@@ -9,20 +9,18 @@
 #' @returns 
 #' Function [print.groupedHyperframe()] does not have a returned value.
 #' 
-#' @seealso `?nlme:::print.groupedData`
-#' 
 #' @keywords internal
-#' @importFrom cli col_blue
+#' @importFrom cli col_blue col_magenta style_bold
 #' @importFrom spatstat.geom as.data.frame.hyperframe as.list.hyperframe
 #' @importFrom utils head
 #' @export print.groupedHyperframe
 #' @export
 print.groupedHyperframe <- function(x, ...) {
+  
+  # @seealso `?nlme:::print.groupedData`
+  
   'Grouped Hyperframe: ' |> cat()
   grp <- attr(x, which = 'group', exact = TRUE)
-  #if (identical(emptyenv(), environment(grp))) {
-  #  environment(grp) <- globalenv()
-  #} # not sure how this is useful in ?nlme:::print.groupedData
   print(grp, ...)
   
   g <- all.vars(grp)
@@ -38,12 +36,12 @@ print.groupedHyperframe <- function(x, ...) {
   
   cat('\n')
   mapply(FUN = \(n, g) {
-    paste(n, col_blue(g))
+    paste(n, g |> col_blue() |> style_bold())
   }, n = ns, g = g, SIMPLIFY = TRUE) |> 
     rev.default() |> 
     cat(sep = ' nested in\n')
-  cat('\n')
   
+  '\nPreview of first 10 (or less) rows:\n\n' |> col_magenta() |> style_bold() |> cat()
   # see inside ?spatstat.geom::print.hyperframe
   x |>
     as.data.frame.hyperframe(discard = FALSE) |> 
@@ -72,43 +70,40 @@ print.groupedHyperframe <- function(x, ...) {
 #' @export [.groupedHyperframe
 #' @export
 `[.groupedHyperframe` <- function(x, ...) {
+  
+  # a super genius fix! 
+  # working on the lowest function `[` :))
+  # no longer needed to write
+  # .. [subset.groupedHyperframe()]
+  # .. probably [split.groupedHyperframe()]
+  
   ret <- `[.hyperframe`(x, ...)
+  
   # a bandage fix hahaha
   group <- attr(x, which = 'group', exact = TRUE)
   if (!all(all.vars(group) %in% names(ret))) return(ret) # just 'hyperframe'
   attr(ret, which = 'group') <- group
-  class(ret) <- unique.default(c('groupedHyperframe', class(ret)))
-  return(ret)
-}
-
-
-#' @importFrom spatstat.geom subset.hyperframe
-#' @export
-subset.groupedHyperframe <- function(x, ...) {
-  ret <- subset.hyperframe(x, ...)
-  # a bandage fix hahaha
-  group <- attr(x, which = 'group', exact = TRUE)
-  if (!all(all.vars(group) %in% names(ret))) return(ret) # just 'hyperframe'
-  attr(ret, which = 'group') <- group
-  class(ret) <- unique.default(c('groupedHyperframe', class(ret)))
+  class(ret) <- c('groupedHyperframe', class(ret)) |> unique.default()
   return(ret)
+  
 }
 
 
 
-#' @title Extract Grouping Formula from [groupedHyperframe]
-#' @description
-#' ..
-#' 
-#' @param object a [groupedHyperframe]
-#' @param asList,sep place holders for S3 generic \link[nlme]{getGroupsFormula}
-#' @returns 
-#' Function [getGroupsFormula.groupedHyperframe()] returns a one-sided \link[stats]{formula}
-#' @keywords internal
-#' @importFrom nlme getGroupsFormula
-#' @export getGroupsFormula.groupedHyperframe
-#' @export
-getGroupsFormula.groupedHyperframe <- function(object, asList, sep) {
-  attr(object, which = 'group', exact = TRUE)
-}
+
+# @title Extract Grouping Formula from [groupedHyperframe]
+# @description ..
+# @param object a [groupedHyperframe]
+# @param asList,sep place holders for S3 generic \link[nlme]{getGroupsFormula}
+# @returns 
+# Function [getGroupsFormula.groupedHyperframe()] returns a one-sided \link[stats]{formula}
+# @note
+# tzh mask this for now, does not want to import(nlme) only for this
+# @keywords internal
+# @importFrom nlme getGroupsFormula
+# @export getGroupsFormula.groupedHyperframe
+# @export
+#getGroupsFormula.groupedHyperframe <- function(object, asList, sep) {
+#  attr(object, which = 'group', exact = TRUE)
+#}
 
